ArucoDetector class

Inheritance
Available extensions

Constructors

ArucoDetector.create(ArucoDictionary dictionary, ArucoDetectorParameters parameters)
factory
ArucoDetector.empty()
factory
ArucoDetector.fromPointer(ArucoDetectorPtr ptr, [bool attach = true])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
no setterinherited
ptr ↔ Pointer<ArucoDetector>
getter/setter pairinherited
ref → ArucoDetector
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

detectMarkers(InputArray image) → (VecVecPoint2f, VecI32, VecVecPoint2f)
DetectMarkers does basic marker detection.
detectMarkersAsync(InputArray image) → Future<(VecVecPoint2f, VecI32, VecVecPoint2f)>

Available on ArucoDetector, provided by the ArucoDetectorAsync extension

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final