ArucoDictionary class

Inheritance

Constructors

ArucoDictionary.empty()
factory
ArucoDictionary.fromBytesList(Mat bytesList, int markerSize, {int maxCorr = 0})
factory
ArucoDictionary.predefined(PredefinedDictionaryType type)
factory

Properties

bytesList ↔ Mat
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
markerSize ↔ int
getter/setter pair
maxCorrectionBits ↔ int
getter/setter pair
props → List<Object?>
no setterinherited
ptr ↔ Pointer<ArucoDictionary>
getter/setter pairinherited
ref → ArucoDictionary
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
generateImageMarker(int id, int sidePixels, {OutputArray? dst, int borderBits = 1}) → Mat
getDistanceToId(InputArray bits, int id, {bool allRotations = true}) → int
identify(InputArray onlyBits, double maxCorrectionRate) → (bool, int, int)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final