CLAHE class

Inheritance

Constructors

CLAHE([double clipLimit = 40, (int, int) tileGridSize = (8, 8)])
factory
CLAHE.create([double clipLimit = 40, (int, int) tileGridSize = (8, 8)])
NewCLAHE returns a new CLAHE algorithm
factory
CLAHE.empty()
factory
CLAHE.fromPointer(CLAHEPtr ptr)
factory

Properties

clipLimit ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
no setterinherited
ptr ↔ Pointer<CLAHE>
getter/setter pairinherited
ref → CLAHE
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tilesGridSize ↔ Size
getter/setter pair

Methods

apply(Mat src, {Mat? dst}) → Mat
Apply CLAHE.
applyAsync(Mat src, {Mat? dst}) → Future<Mat>
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final