Feature2D<T extends Struct> class abstract

Inheritance

Constructors

Feature2D.fromPointer(Pointer<T> ptr)

Properties

defaultName → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
props → List<Object?>
no setterinherited
ptr ↔ Pointer<T>
getter/setter pairinherited
ref → T
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect(Mat src, {VecKeyPoint? keypoints, Mat? mask}) → VecKeyPoint
detectAndCompute(Mat src, Mat mask, {VecKeyPoint? keypoints, Mat? descriptors, bool useProvidedKeypoints = false}) → (VecKeyPoint, Mat)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited