FlannIndexParams class

Inheritance

Constructors

FlannIndexParams.empty()
factory
FlannIndexParams.fromMap(Map<String, dynamic> map)
factory
FlannIndexParams.fromPointer(FlannIndexParamsPtr ptr, [bool attach = true])

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
no setterinherited
ptr ↔ Pointer<FlannIndexParams>
getter/setter pairinherited
ref → FlannIndexParams
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get<T>(String key, [T? defaultValue]) → T
getAll() → Map<String, dynamic>
getDouble(String key, [double defaultValue = -1]) → double
getInt(String key, [int defaultValue = -1]) → int
getString(String key, [String defaultValue = ""]) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set<T>(String key, T value) → void
setAlgorithm(FlannAlgorithm value) → void
setBool(String key, bool value) → void
setDouble(String key, double value) → void
setInt(String key, int value) → void
setString(String key, String value) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final