QualityMSE class

Inheritance

Constructors

QualityMSE.create(Mat img)
Create an object which calculates quality.
factory
QualityMSE.fromPointer(Pointer<QualityMSE> ptr, [bool attach = true])

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
no setterinherited
ptr ↔ Pointer<QualityMSE>
getter/setter pairinherited
ref → QualityMSE
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compute(Mat cmpImgs) → Scalar
Computes MSE for reference images supplied in class constructor and provided comparison images.
computeAsync(Mat cmpImgs) → Future<Scalar>
async version of compute
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final

Static Methods

compute1(Mat img, Mat cmp, {Mat? qualityMap}) → (Scalar, Mat)
static method for computing quality
compute1Async(Mat img, Mat cmp, {Mat? qualityMap}) → Future<(Scalar, Mat)>
async version of compute1