StereoBM class

Class for computing stereo correspondence using the block matching algorithm, introduced and contributed to OpenCV by K. Konolige.

This class implements a block matching algorithm for stereo correspondence, which is used to compute disparity maps from stereo image pairs. It provides methods to fine-tune parameters such as pre-filtering, texture thresholds, uniqueness ratios, and regions of interest (ROIs) to optimize performance and accuracy.

https://docs.opencv.org/4.x/d9/dba/classcv_1_1StereoBM.html#details

Inheritance

Constructors

StereoBM.create({int numDisparities = 0, int blockSize = 21})
Creates StereoBM object.
factory
StereoBM.fromPointer(StereoBMPtr ptr)
factory

Properties

blockSize ↔ int
getter/setter pair
disp12MaxDiff ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
minDisparity ↔ int
getter/setter pair
numDisparities ↔ int
getter/setter pair
preFilterCap ↔ int
getter/setter pair
preFilterSize ↔ int
getter/setter pair
preFilterType ↔ int
getter/setter pair
props → List<Object?>
no setterinherited
ptr ↔ Pointer<StereoBM>
getter/setter pairinherited
ref → StereoBM
no setteroverride
ROI1 ↔ Rect
getter/setter pair
ROI2 ↔ Rect
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smallerBlockSize ↔ int
Warning: do nothing
getter/setter pair
speckleRange ↔ int
getter/setter pair
speckleWindowSize ↔ int
getter/setter pair
textureThreshold ↔ int
getter/setter pair
uniquenessRatio ↔ int
getter/setter pair

Methods

compute(Mat left, Mat right, {Mat? disparity}) → Mat
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final

Constants

PREFILTER_NORMALIZED_RESPONSE → const int
Pre-filter types for the stereo matching algorithm. Uses normalized response for pre-filtering.
PREFILTER_XSOBEL → const int
Pre-filter types for the stereo matching algorithm. Uses the X-Sobel operator for pre-filtering.