TermCriteria class

TermCriteria is the criteria for iterative algorithms.

For further details, please see: https://docs.opencv.org/master/d9/d5d/classcv_1_1TermCriteria.html

Inheritance

Constructors

TermCriteria(int type, int cound, double eps)
factory
TermCriteria.fromPointer(Pointer<TermCriteria> ptr, [bool attach = true])
TermCriteria.fromRecord((int, int, double) record)
factory

Properties

eps → double
no setter
hashCode → int
The hash code for this object.
no setterinherited
maxCount → int
no setter
props → List<num>
no setteroverride
ptr ↔ Pointer<TermCriteria>
getter/setter pairinherited
ref → TermCriteria
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → int
no setter

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final