UsacParams class

Inheritance

Constructors

UsacParams({double confidence = 0, bool isParallel = false, int loIterations = 0, int loMethod = LOCAL_OPTIM_NULL, int loSampleSize = 0, int maxIterations = 0, int neighborsSearch = NEIGH_FLANN_KNN, int randomGeneratorState = 0, int sampler = SAMPLING_UNIFORM, int score = SCORE_METHOD_RANSAC, double threshold = 0, int finalPolisher = NONE_POLISHER, int finalPolisherIterations = 0})
factory
UsacParams.fromPointer(Pointer<UsacParams> ptr, [bool attach = true])

Properties

confidence ↔ double
double confidence;
getter/setter pair
finalPolisher ↔ int
int finalPolisher;
getter/setter pair
finalPolisherIterations ↔ int
int finalPolisherIterations;
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isParallel ↔ bool
bool isParallel;
getter/setter pair
loIterations ↔ int
int loIterations;
getter/setter pair
loMethod ↔ int
int loMethod;
getter/setter pair
loSampleSize ↔ int
int loSampleSize;
getter/setter pair
maxIterations ↔ int
int maxIterations;
getter/setter pair
neighborsSearch ↔ int
int neighborsSearch;
getter/setter pair
props → List<Object?>
no setterinherited
ptr ↔ Pointer<UsacParams>
getter/setter pairinherited
randomGeneratorState ↔ int
int randomGeneratorState;
getter/setter pair
ref → UsacParams
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampler ↔ int
int sampler;
getter/setter pair
score ↔ int
int score;
getter/setter pair
threshold ↔ double
double threshold;
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final