Vec3s class

short

Inheritance

Constructors

Vec3s(int v1, int v2, int v3)
factory
Vec3s.fromNative(Vec3s v)
factory
Vec3s.fromPointer(Pointer<Vec3s> ptr, [bool attach = true])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<int>
no setteroverride
ptr ↔ Pointer<Vec3s>
getter/setter pairinherited
ref → Vec3s
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
val ↔ List<int>
getter/setter pairoverride
val1 ↔ int
getter/setter pair
val2 ↔ int
getter/setter pair
val3 ↔ int
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final