Vec8i class

int

Inheritance

Constructors

Vec8i(int v1, int v2, int v3, int v4, int v5, int v6, int v7, int v8)
factory
Vec8i.fromNative(Vec8i v)
factory
Vec8i.fromPointer(Pointer<Vec8i> ptr, [bool attach = true])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<int>
no setteroverride
ptr ↔ Pointer<Vec8i>
getter/setter pairinherited
ref → Vec8i
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
val ↔ List<int>
getter/setter pairoverride
val1 ↔ int
getter/setter pair
val2 ↔ int
getter/setter pair
val3 ↔ int
getter/setter pair
val4 ↔ int
getter/setter pair
val5 ↔ int
getter/setter pair
val6 ↔ int
getter/setter pair
val7 ↔ int
getter/setter pair
val8 ↔ int
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

finalizer → NativeFinalizer
final