VecVecChar class

Inheritance

Constructors

VecVecChar([int length = 0])
factory
VecVecChar.fromList(List<List<int>> pts)
factory
VecVecChar.fromPointer(Pointer<VecVecChar> ptr, {bool attach = true, int? externalSize})
VecVecChar.generate(int length, Iterable<int> generator(int count))
factory

Properties

first → VecChar
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<VecChar>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last → VecChar
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setteroverride
ptr ↔ Pointer<VecVecChar>
getter/setter pairinherited
ref → VecVecChar
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → VecChar
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

add(VecChar element) → void
inherited
any(bool test(VecChar element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
asStringList() → List<String>
asVoid() → Pointer<Void>
override
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
clear() → void
inherited
clone() → VecVecChar
override
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
dispose() → void
override
elementAt(int index) → VecChar
Returns the indexth element.
inherited
every(bool test(VecChar element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(VecChar element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
extend(Vec<Struct, dynamic> other) → void
inherited
firstWhere(bool test(VecChar element), {VecChar orElse()?}) → VecChar
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, VecChar element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<VecChar> other) → Iterable<VecChar>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(VecChar element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(VecChar element), {VecChar orElse()?}) → VecChar
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(VecChar e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(VecChar combine(VecChar value, VecChar element)) → VecChar
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
reserve(int newCapacity) → void
inherited
resize(int newSize) → void
inherited
shrinkToFit() → void
inherited
singleWhere(bool test(VecChar element), {VecChar orElse()?}) → VecChar
The single element that satisfies test.
inherited
size() → int
override
skip(int count) → Iterable<VecChar>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(VecChar element)) → Iterable<VecChar>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<VecChar>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(VecChar element)) → Iterable<VecChar>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<VecChar>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<VecChar>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
where(bool test(VecChar element)) → Iterable<VecChar>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int idx) → VecChar
Returns a reference
override
operator []=(int idx, VecChar value) → void
inherited

Static Properties

finalizer → NativeFinalizer
final